@@ -1,10 +1,10 @@
-from typing import Mapping
+from typing import Mapping, Optional, Sequence, Type
 
 import dagster._check as check
 from dagster import InputContext, MetadataValue, OutputContext, TableColumn, TableSchema
 from dagster._core.definitions.metadata import RawMetadataValue
 from dagster._core.storage.db_io_manager import DbTypeHandler, TableSlice
-from dagster_snowflake import build_snowflake_io_manager
+from dagster_snowflake import SnowflakeIOManager, build_snowflake_io_manager
 from dagster_snowflake.snowflake_io_manager import SnowflakeDbClient
 from pyspark.sql import DataFrame, SparkSession
 from pyspark.sql.types import StructType
@@ -36,30 +36,29 @@ class SnowflakePySparkTypeHandler(DbTypeHandler[DataFrame]):
     Examples:
         .. code-block:: python
 
-            from dagster_snowflake import build_snowflake_io_manager
+            from dagster_snowflake import SnowflakeIOManager
+            from dagster_snowflake_pandas import SnowflakePandasTypeHandler
             from dagster_snowflake_pyspark import SnowflakePySparkTypeHandler
-            from pyspark.sql import DataFrame
-            from dagster import Definitions
+            from dagster import Definitions, EnvVar
 
-            snowflake_io_manager = build_snowflake_io_manager([SnowflakePySparkTypeHandler()])
+            class MySnowflakeIOManager(SnowflakeIOManager):
+                @staticmethod
+                def type_handlers() -> Sequence[DbTypeHandler]:
+                    return [SnowflakePandasTypeHandler(), SnowflakePySparkTypeHandler()]
 
-            @asset
-            def my_asset() -> DataFrame:
+            @asset(
+                key_prefix=["my_schema"]  # will be used as the schema in snowflake
+            )
+            def my_table() -> pd.DataFrame:  # the name of the asset will be the table name
                 ...
 
             defs = Definitions(
-                assets=[my_asset],
+                assets=[my_table],
                 resources={
-                    "io_manager": snowflake_io_manager.configured(...)
+                    "io_manager": MySnowflakeIOManager(database="MY_DATABASE", account=EnvVar("SNOWFLAKE_ACCOUNT"), warehouse="my_warehouse", ...)
                 }
             )
 
-            # OR
-
-            @job(resource_defs={'io_manager': snowflake_io_manager})
-            def my_job():
-                ...
-
     """
 
     def handle_output(
@@ -87,7 +86,7 @@ class SnowflakePySparkTypeHandler(DbTypeHandler[DataFrame]):
     def load_input(self, context: InputContext, table_slice: TableSlice, _) -> DataFrame:
         options = _get_snowflake_options(context.resource_config, table_slice)
 
-        spark = SparkSession.builder.getOrCreate()
+        spark = SparkSession.builder.getOrCreate()  # type: ignore
         if table_slice.partition_dimensions and len(context.asset_partition_keys) == 0:
             return spark.createDataFrame([], StructType([]))
 
@@ -108,7 +107,7 @@ snowflake_pyspark_io_manager = build_snowflake_io_manager(
     [SnowflakePySparkTypeHandler()], default_load_type=DataFrame
 )
 snowflake_pyspark_io_manager.__doc__ = """
-An IO manager definition that reads inputs from and writes PySpark DataFrames to Snowflake. When
+An I/O manager definition that reads inputs from and writes PySpark DataFrames to Snowflake. When
 using the snowflake_pyspark_io_manager, any inputs and outputs without type annotations will be loaded
 as PySpark DataFrames.
 
@@ -145,7 +144,7 @@ Examples:
     Note that the warehouse configuration value is required when using the snowflake_pyspark_io_manager
 
     If you do not provide a schema, Dagster will determine a schema based on the assets and ops using
-    the IO Manager. For assets, the schema will be determined from the asset key.
+    the I/O Manager. For assets, the schema will be determined from the asset key.
     For ops, the schema can be specified by including a "schema" entry in output metadata. If "schema" is not provided
     via config or on the asset/op, "public" will be used for the schema.
 
@@ -171,3 +170,76 @@ Examples:
             ...
 
 """
+
+
+class SnowflakePySparkIOManager(SnowflakeIOManager):
+    """An I/O manager definition that reads inputs from and writes PySpark DataFrames to Snowflake. When
+    using the SnowflakePySparkIOManager, any inputs and outputs without type annotations will be loaded
+    as PySpark DataFrames.
+
+    Returns:
+        IOManagerDefinition
+
+    Examples:
+        .. code-block:: python
+
+            from dagster_snowflake_pyspark import SnowflakePySparkIOManager
+            from pyspark.sql import DataFrame
+            from dagster import Definitions, EnvVar
+
+            @asset(
+                key_prefix=["my_schema"]  # will be used as the schema in snowflake
+            )
+            def my_table() -> DataFrame:  # the name of the asset will be the table name
+                ...
+
+            defs = Definitions(
+                assets=[my_table],
+                resources={
+                    "io_manager": SnowflakePySparkIOManager(
+                        database="my_database",
+                        warehouse="my_warehouse", # required for SnowflakePySparkIOManager
+                        account=EnvVar("SNOWFLAKE_ACCOUNT"),
+                        password=EnvVar("SNOWFLAKE_PASSWORD"),
+                        ...
+                    )
+                }
+            )
+
+        Note that the warehouse configuration value is required when using the SnowflakePySparkIOManager
+
+        If you do not provide a schema, Dagster will determine a schema based on the assets and ops using
+        the I/O Manager. For assets, the schema will be determined from the asset key, as in the above example.
+        For ops, the schema can be specified by including a "schema" entry in output metadata. If "schema" is not provided
+        via config or on the asset/op, "public" will be used for the schema.
+
+        .. code-block:: python
+
+            @op(
+                out={"my_table": Out(metadata={"schema": "my_schema"})}
+            )
+            def make_my_table() -> DataFrame:
+                # the returned value will be stored at my_schema.my_table
+                ...
+
+        To only use specific columns of a table as input to a downstream op or asset, add the metadata "columns" to the
+        In or AssetIn.
+
+        .. code-block:: python
+
+            @asset(
+                ins={"my_table": AssetIn("my_table", metadata={"columns": ["a"]})}
+            )
+            def my_table_a(my_table: DataFrame) -> DataFrame:
+                # my_table will just contain the data from column "a"
+                ...
+
+    """
+
+    @staticmethod
+    def type_handlers() -> Sequence[DbTypeHandler]:
+        return [SnowflakePySparkTypeHandler()]
+
+    @staticmethod
+    def default_load_type() -> Optional[Type]:
+        return DataFrame
